@@ -19,13 +19,17 @@ impl<'info> Validate<'info> for NewRewarder<'info> {
     fn validate(&self) -> Result<()> {
         invariant!(self.base.is_signer, Unauthorized);
 
+        assert_keys_eq!(self.mint_wrapper.token_mint, self.rewards_token_mint);
+        assert_keys_eq!(
+            self.rewards_token_mint.mint_authority.unwrap(),
+            self.mint_wrapper
+        );
+
         assert_keys_eq!(self.claim_fee_token_account.owner, self.rewarder);
         assert_keys_eq!(self.claim_fee_token_account.mint, self.rewards_token_mint);
         invariant!(self.claim_fee_token_account.delegate.is_none());
         invariant!(self.claim_fee_token_account.close_authority.is_none());
 
-        assert_keys_eq!(self.mint_wrapper.token_mint, self.rewards_token_mint);
-
         Ok(())
     }
 }
@@ -44,7 +48,7 @@ impl<'info> Validate<'info> for MutableRewarderWithPauseAuthority<'info> {
         assert_keys_eq!(
             self.rewarder.pause_authority,
             self.pause_authority,
-            "pause_authority"
+            Unauthorized
         );
         Ok(())
     }
@@ -52,16 +56,16 @@ impl<'info> Validate<'info> for MutableRewarderWithPauseAuthority<'info> {
 
 impl<'info> Validate<'info> for TransferAuthority<'info> {
     fn validate(&self) -> Result<()> {
-        invariant!(!self.rewarder.is_paused, Paused);
+        self.rewarder.assert_not_paused()?;
         invariant!(self.authority.is_signer, Unauthorized);
-        assert_keys_eq!(self.authority, self.rewarder.authority);
+        assert_keys_eq!(self.authority, self.rewarder.authority, Unauthorized);
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for AcceptAuthority<'info> {
     fn validate(&self) -> Result<()> {
-        invariant!(!self.rewarder.is_paused, Paused);
+        self.rewarder.assert_not_paused()?;
         invariant!(
             self.rewarder.pending_authority != Pubkey::default(),
             PendingAuthorityNotSet
@@ -69,7 +73,7 @@ impl<'info> Validate<'info> for AcceptAuthority<'info> {
         assert_keys_eq!(
             self.rewarder.pending_authority,
             self.authority,
-            "pending authority"
+            Unauthorized
         );
         Ok(())
     }
@@ -77,8 +81,8 @@ impl<'info> Validate<'info> for AcceptAuthority<'info> {
 
 impl<'info> Validate<'info> for SetAnnualRewards<'info> {
     fn validate(&self) -> Result<()> {
+        self.auth.rewarder.assert_not_paused()?;
         self.auth.validate()?;
-        invariant!(!self.auth.rewarder.is_paused, Paused);
         Ok(())
     }
 }
@@ -97,26 +101,26 @@ impl<'info> Validate<'info> for CreateQuarry<'info> {
 
 impl<'info> Validate<'info> for SetRewardsShare<'info> {
     fn validate(&self) -> Result<()> {
+        assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder);
+        self.auth.rewarder.assert_not_paused()?;
         self.auth.validate()?;
-        invariant!(!self.auth.rewarder.is_paused, Paused);
-        assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder, "rewarder");
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for SetFamine<'info> {
     fn validate(&self) -> Result<()> {
+        assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder);
+        self.auth.rewarder.assert_not_paused()?;
         self.auth.validate()?;
-        invariant!(!self.auth.rewarder.is_paused, Paused);
-        assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder, "rewarder");
         Ok(())
     }
 }
 
 impl<'info> Validate<'info> for UpdateQuarryRewards<'info> {
     fn validate(&self) -> Result<()> {
-        invariant!(!self.rewarder.is_paused, Paused);
-        assert_keys_eq!(self.quarry.rewarder_key, self.rewarder, "rewarder");
+        assert_keys_eq!(self.quarry.rewarder_key, self.rewarder);
+        self.rewarder.assert_not_paused()?;
         Ok(())
     }
 }
@@ -148,48 +152,33 @@ impl<'info> Validate<'info> for ClaimRewards<'info> {
     /// Validates a [ClaimRewards] accounts struct.
     fn validate(&self) -> Result<()> {
         self.stake.validate()?;
-        invariant!(!self.stake.rewarder.is_paused, Paused);
+        self.stake.rewarder.assert_not_paused()?;
 
-        assert_keys_eq!(
-            self.mint_wrapper.token_mint,
-            self.rewards_token_mint,
-            "mint_wrapper.token_mint",
-        );
-        assert_keys_eq!(
-            self.minter.minter_authority,
-            self.stake.rewarder,
-            "minter.minter_authority"
-        );
+        assert_keys_eq!(self.mint_wrapper, self.stake.rewarder.mint_wrapper);
+        assert_keys_eq!(self.mint_wrapper.token_mint, self.rewards_token_mint);
+
+        assert_keys_eq!(self.minter.mint_wrapper, self.mint_wrapper);
+        assert_keys_eq!(self.minter.minter_authority, self.stake.rewarder);
 
         // rewards_token_mint validate
         assert_keys_eq!(
             self.rewards_token_mint,
-            self.stake.rewarder.rewards_token_mint,
-            "rewards token mint",
+            self.stake.rewarder.rewards_token_mint
         );
         assert_keys_eq!(
             self.rewards_token_mint.mint_authority.unwrap(),
-            *self.mint_wrapper,
-            "mint wrapper",
+            self.mint_wrapper
         );
 
         // rewards_token_account validate
-        assert_keys_eq!(
-            self.rewards_token_account.mint,
-            self.rewards_token_mint,
-            "rewards_token_account.mint",
-        );
+        assert_keys_eq!(self.rewards_token_account.mint, self.rewards_token_mint);
 
         // claim_fee_token_account validate
         assert_keys_eq!(
             self.claim_fee_token_account,
             self.stake.rewarder.claim_fee_token_account
         );
-        assert_keys_eq!(
-            self.claim_fee_token_account.mint,
-            self.rewards_token_mint,
-            "rewards_token_account.mint",
-        );
+        assert_keys_eq!(self.claim_fee_token_account.mint, self.rewards_token_mint);
 
         Ok(())
     }
@@ -215,32 +204,26 @@ impl<'info> Validate<'info> for UserClaim<'info> {
 impl<'info> Validate<'info> for UserStake<'info> {
     /// Validates the UserStake.
     fn validate(&self) -> Result<()> {
-        invariant!(!self.rewarder.is_paused, Paused);
+        self.rewarder.assert_not_paused()?;
+
         // authority
         invariant!(self.authority.is_signer, Unauthorized);
-        assert_keys_eq!(self.authority, self.miner.authority, "miner authority");
+        assert_keys_eq!(self.authority, self.miner.authority);
 
         // quarry
-        assert_keys_eq!(self.miner.quarry_key, self.quarry.key(), "quarry");
+        assert_keys_eq!(self.miner.quarry_key, self.quarry);
 
         // miner_vault
-        assert_keys_eq!(self.miner.token_vault_key, self.miner_vault, "miner vault");
-        assert_keys_eq!(
-            self.miner_vault.mint,
-            self.quarry.token_mint_key,
-            "vault mint"
-        );
-        assert_keys_eq!(self.miner_vault.owner, self.miner, "vault owner");
+        let staked_mint = self.quarry.token_mint_key;
+        assert_keys_eq!(self.miner.token_vault_key, self.miner_vault);
+        assert_keys_eq!(self.miner_vault.mint, staked_mint);
+        assert_keys_eq!(self.miner_vault.owner, self.miner);
 
         // token_account
-        assert_keys_eq!(
-            self.token_account.mint,
-            self.quarry.token_mint_key,
-            "token mint"
-        );
+        assert_keys_eq!(self.token_account.mint, staked_mint);
 
         // rewarder
-        assert_keys_eq!(self.quarry.rewarder_key, self.rewarder, "rewarder");
+        assert_keys_eq!(self.quarry.rewarder_key, self.rewarder);
 
         Ok(())
     }
@@ -248,7 +231,7 @@ impl<'info> Validate<'info> for UserStake<'info> {
 
 impl<'info> Validate<'info> for ExtractFees<'info> {
     fn validate(&self) -> Result<()> {
-        invariant!(!self.rewarder.is_paused, Paused);
+        self.rewarder.assert_not_paused()?;
 
         assert_keys_eq!(
             self.claim_fee_token_account,
@@ -263,16 +246,10 @@ impl<'info> Validate<'info> for ExtractFees<'info> {
 
         assert_keys_eq!(
             self.fee_to_token_account.mint,
-            self.rewarder.rewards_token_mint,
-            "fee_to_token_account.mint"
+            self.rewarder.rewards_token_mint
         );
-        assert_keys_eq!(
-            self.fee_to_token_account.owner,
-            addresses::FEE_TO,
-            "fee_to_token_account.owner"
-        );
-
         assert_keys_eq!(self.fee_to_token_account.owner, addresses::FEE_TO);
+
         assert_keys_eq!(
             self.fee_to_token_account.mint,
             self.rewarder.rewards_token_mint
@@ -280,6 +257,8 @@ impl<'info> Validate<'info> for ExtractFees<'info> {
         invariant!(self.fee_to_token_account.delegate.is_none());
         invariant!(self.fee_to_token_account.close_authority.is_none());
 
+        assert_keys_neq!(self.claim_fee_token_account, self.fee_to_token_account);
+
         Ok(())
     }
 }
@@ -287,7 +266,7 @@ impl<'info> Validate<'info> for ExtractFees<'info> {
 impl<'info> Validate<'info> for MutableRewarderWithAuthority<'info> {
     fn validate(&self) -> Result<()> {
         invariant!(self.authority.is_signer, Unauthorized);
-        assert_keys_eq!(self.rewarder.authority, self.authority, "authority");
+        assert_keys_eq!(self.rewarder.authority, self.authority, Unauthorized);
         Ok(())
     }
 }
